
# q-expansion of newform 310.8.a.f, downloaded from the LMFDB on 16 November 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 310
weight = 8
poly_data = [-3739212331975008, 396841300513056, 39115051614720, -1179858332736, -93411415542, 753120238, 65389315, -76284, -14812, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[47844312425825814221877361154986332564528, -2369069892826608799436411646775150930296, -136588397732502820277641726807285606908, 3425918149185996732611014055717933346, 87356104991232770336749420577014884, -1199967324297822330596257959476381, -17392032515122181034288101078412, 145122137597756142324714649128, 1063648990801354242090238034, -5482065402626707290190679], 6251597054878500444484108628362058112], [[28632856655721794239653246893532978790704, 1272151412210179646028570396535993179720, -138731580536826234634046220964349790972, -6688331400070980578343024787727031822, 100705927037448511884205962997883796, 5242110169954020358852855863596203, -15764706393588885768351846898476, -1202799234517905292832896274712, 659174792617918884706392434, 80987651100087476605199425], 6251597054878500444484108628362058112], [[12823466535291335339552694540137810485488, -991403274744958374531807155191608453720, -51867334141895408679304328581443600300, 3438407226837305695431136856284829994, 48739237069262205911123423025025428, -2611700368947199387672016228373425, -17006756052445836157649831759676, 640226611094918629004240202696, 1457272871885979514283930810, -45556342022130795666410771], 2083865684959500148161369542787352704], [[1773216484686669502852063439067682293456, -294659185068630252105381670546230876072, -5245975957768714988366160007101993444, 909730523684381415552873662971867542, 4487797018197154385673455184587124, -664486235579895207606845266256327, -2016472406613558112003561461156, 155169970356562625346321916344, 190911140720964402193465262, -10687532326957193962309109], 446542646777035746034579187740147008], [[6795442744754761672598400176329745540976, -658051946598047567178101463202765375800, -15939487720618991497990386136920327948, 1951018008174369794464014184803640290, 11532140686722899141864922475754924, -1510493775694714120802160926121461, -5311900295428898175703604159532, 368068501312201547913959174824, 511377352726811261224499770, -25975481941439628869061503], 1041932842479750074080684771393676352], [[-1915318742111358798324886991928504873648, 165730433097148609231350999722513167992, 5355990456787604637505366735850185572, -541796051276673592234224909499358478, -5358302950688709546279207523846924, 423872096028026575330553110837315, 2190326345155194416658368789556, -104770031817048938793291426728, -199002739777727251458609566, 7465513473651966721433881], 260483210619937518520171192848419088], [[26137725059867932941582123098011626474096, -4076385880865709077291820125007222380856, -97867918658393010346385466565735151916, 12869666281110753015680814554795374530, 95714214535644595255064676578272956, -9737868801395585357214554193842069, -40399222988157239783925355702764, 2343430174300525642943750535144, 3724410862379477832857571626, -164398887972523958393370335], 3125798527439250222242054314181029056], [[-30293040504473602396992575400534141142224, 4242716347701322403570895437855470449096, 108154576793981536222409964140430393252, -11542585783088887077514730215690661358, -105551972892316385803202472554106268, 8262595953752842574144805752142955, 40695518640093577282379528651988, -1966909677982459411679815053080, -3626444047751609360686821278, 137843121362371609000417729], 2083865684959500148161369542787352704]]

hecke_ring_character_values = None
aps_data = [[-8, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [-125, 0, 0, 0, 0, 0, 0, 0, 0, 0], [52, -2, 0, 0, 0, 1, 0, 0, 0, 0], [-239, -1, 0, -1, -1, 0, 0, 0, 0, -1], [-915, -22, 0, 2, 1, 4, -1, -1, -2, 1], [-4319, 117, 2, 0, 0, -8, 5, -4, -1, 5], [395, 97, -2, -3, 6, -5, -1, -7, 3, -1], [1829, -27, 12, 3, 11, -24, -10, 5, -16, 1], [22439, 363, 2, -23, -23, -34, 10, 16, -18, -1], [29791, 0, 0, 0, 0, 0, 0, 0, 0, 0], [12957, -705, -27, 20, 76, 42, 74, -4, -15, -37], [-26755, -1101, 38, -17, 64, -271, -80, 25, 162, 41], [-100299, -5407, -1, 14, 146, 191, -15, -84, -32, 71], [-140653, -4605, -96, -55, -154, 245, 88, -44, -181, 123], [-119500, -8123, 118, 180, -16, 167, -75, -90, -149, -128], [16194, -21190, -2, 62, -372, -137, 89, -1, 150, -98], [343358, -16408, -113, 242, -52, -196, -479, 196, -98, -210], [-49763, -17041, -121, -187, 411, 1291, 128, -418, -531, -33], [287451, 4403, -234, 161, 142, -1175, -377, 289, -509, -257], [199864, -21882, -643, -249, -171, 438, -86, -170, -315, 184], [1599577, 8897, 413, 45, -423, -1530, 707, 320, -214, 149], [324319, 20672, -473, 227, 135, -2486, 927, 360, 1044, -161], [-675305, -86457, -319, -1177, -1945, 122, 659, -502, -622, 409], [247227, 3013, -645, -345, 809, 1964, -1706, -104, 1315, 1091], [-157819, -35129, -879, 559, 3019, 2401, 950, 881, -2800, -157], [-2096114, 52946, -525, 2352, 3065, 943, -142, 788, -3180, -396], [-590430, 48646, 1227, 1664, -389, 4001, 748, 628, 2510, -240], [-948537, -9179, 617, -1741, -377, 107, 3172, -533, -2062, -299], [-5799750, 159054, -825, -2018, -1797, -394, -2358, -606, 3494, -2590], [-3236173, -178067, 3762, -567, 5303, 4208, -594, 4005, 3358, 983], [-4819717, 74631, 2574, 401, 42, -6521, -6295, -1459, 13015, 2059], [-12982478, -232670, -1299, 2645, -7689, -2752, -2128, 4742, -2075, 10], [-8503431, -57314, -1862, 6638, -8186, -12965, -8354, 3676, 2166, -935], [-12447574, 149510, -1539, 2200, -9425, -13603, 2994, 1557, 9197, -3484], [-8178917, -211205, -6053, -1051, -735, -2122, 4507, 5800, -6590, 3687], [-28224129, 188203, 3230, -2801, 7846, -26044, 1946, 5954, 16573, 3109], [-31995964, 84940, -6993, 1478, -2407, -25389, -6972, -318, 10544, -8874], [-32073965, -474495, 6046, 774, 1506, -27017, 8482, 15202, 5576, -2505], [-30080209, 295041, -6848, -3719, -14362, 5846, 10158, -2526, -16115, 6365], [-23513409, 40654, -6566, -9132, 23310, -1669, 14698, -1964, 200, 4623], [-16476228, 275875, 12547, 4717, 3663, 2357, 5395, -5048, -23238, 13926], [-20372379, -459569, 12991, -1659, -157, -56552, -8836, 9776, 8213, -12717], [20869858, 289876, 18320, -9504, 31830, 1750, 25592, 6734, 1242, 14776], [-24441639, 433133, -1916, 8021, -7708, -21267, -29907, 27291, 24252, -11705], [21587377, -879175, 11735, 1055, -9707, -6308, -19537, 12680, 39574, -14131], [22015890, -100614, -20166, -19612, -61914, -59528, 38938, -2990, 11944, -17162], [32013544, -523216, -14525, 11473, 37521, -39267, 48471, 11334, -31368, 22776], [-43776231, 1006141, -13615, 37329, -21737, -15911, -49116, 12120, 4357, -20373], [1708487, -437665, -20604, -34711, -23157, 56382, -20392, -55372, 26152, -14849], [10817808, 674516, 28849, 50662, -5017, 56302, 9990, 8970, -67154, 20432], [-41378136, -142696, 29560, -10200, -7336, -26218, 18702, 3024, -13336, 41868], [-7165083, 897835, -18079, -18817, 48719, 41422, -2845, -63790, 10678, 1823], [-40255762, -587634, -18081, 19502, -48430, 93552, -609, 18882, 6544, 8752], [-103056627, -937483, -23940, 28853, 44674, -95558, 31888, -6362, -50207, 26059], [-106874760, -151460, 25327, 10257, 69901, -38999, 6479, -44806, -18548, 1312], [-2779463, 243054, -21294, 1526, -89692, 239653, -9428, -44546, -49008, -9985], [117298357, -1192729, 61355, -44571, -70971, -31948, -43701, 64170, 88986, -26027], [-92927176, 408897, -54270, -7706, 33462, -103281, -70477, 614, 24595, -83532], [23690895, 688303, -39215, -59307, -84191, 22581, 56064, 42693, 22478, -40179], [73432180, -213700, -42495, -51310, -97001, -10203, 2032, -8204, -27214, -19458], [-68799777, 1727835, 41842, 70387, -3966, -80038, -127460, -2378, 108941, 45637], [-106968563, -4187893, 9289, -3075, -150247, 66535, -39540, -93750, 17907, -51253], [-20881826, 604416, -11560, 120326, 97560, -11375, -48597, 58485, 124474, -5962], [116268378, 3257774, -3091, -66207, 46245, -764, 116034, 56574, 130363, -5238], [-27272456, -948788, -23162, 83046, 122206, 66360, 27826, -78776, -184288, 80682], [141666144, -4566017, -42201, -37203, 131917, -53233, -133319, 47848, 102318, -22584], [274836265, 500425, 22756, 112910, -312030, 13656, -116547, 35364, 273639, -71423], [33228827, -1097592, 121799, -49350, 247404, -292687, -18301, 19475, -12194, 38811], [228635426, -1884134, 24579, -83582, 207743, -192697, 116924, -409, 130655, -37540], [-110209327, 8010963, 31565, -60337, -137234, -238075, -29934, -39279, -27218, -167983], [258704371, -5340235, -72737, -18619, -191359, 25902, 57922, 85780, -153765, 103273], [-190220039, 508411, -29694, -93266, 85760, 352147, 239756, -90754, -47910, 11389], [-197745675, 1842753, 110716, 190309, 56056, -253802, -198024, 96258, -306545, 32327], [243550052, -2453390, -81442, 136328, 128332, -36183, -39667, -218797, -401306, -37216], [-245015442, 6355340, -75259, -114041, -106795, -430937, -60353, -149894, 399472, 97918], [218150546, 2233679, -140585, 118613, -59873, -423635, 308737, 42016, -76244, -119184], [-405765308, -1235534, -132368, -243818, 339480, -18112, 184004, -106186, -451734, 84738], [-247619687, 1777677, 110651, -426573, -51445, -489740, 205883, 176828, -104810, 54447], [106528357, 9518877, -264291, -40617, -110823, -481464, -30733, -291202, -446832, -40149], [185078838, 619156, -162452, 388226, -145690, 12027, -245195, -135551, -219778, 24554], [-647405440, 21650506, 134231, -252628, 324503, 166293, 102356, -285769, -144325, 87394], [-430256578, 7462720, -243399, -165284, -98291, 1332023, -66533, 144379, -295844, -341700], [228249467, 6500399, -174207, -25721, -55738, -240137, 59930, 384257, 715858, 320931], [470110877, 4635285, -103731, -152013, -36173, -514261, 510241, -50207, 281153, -123809], [-268270816, 8673208, 96707, -254446, -304535, 149315, 312356, -194422, 352418, 214450], [-183121316, -4581020, 26292, 10160, 436780, 183156, -137486, -560, -235838, -337394], [-79794435, 14557191, -151509, 309351, -716676, -230029, -99706, 55523, 610882, -305875], [-992334155, 24765438, -99348, 74660, 697212, 904165, 176668, -246572, -778628, 177463], [3312463, 11989897, 148718, 222223, 502483, -658714, -387678, 358497, -205334, 54043], [-490503578, 17649168, -48081, -381308, -803537, -480783, 252636, 87462, 42110, -42424], [294324008, -12551584, -195550, -315678, 94036, -371582, 242698, 242920, 480704, 331436], [-281299516, -7202548, -68659, 530827, 796491, -1622485, -26655, 387378, 256324, -80492], [-1037500284, 24139547, -22877, 302587, 44227, 1107607, -207069, 124440, -586818, -275124], [817662171, -2207747, -278522, -282755, -201867, -885062, -419152, -47854, -232448, 2825], [-130097897, 14356511, -234637, 471241, 128851, 478435, 232358, -490822, -1006269, 511613], [519755774, 20506965, 12167, 607065, 128583, -36903, -632435, -249344, -395844, -262340], [97474361, 46052533, -52495, 118679, -619671, 393877, -939876, 563409, 854192, -613073], [253051613, -2346283, 41439, 247358, 232882, -511045, -274035, -244692, -873546, -316177], [241361594, 44934778, 55902, 569390, -139826, -761846, 19136, 278780, 537966, -465892], [-632232479, -26313385, 16097, -64671, -1306181, -307263, -1217350, -692422, -704265, -400589], [454819919, 2455743, 342754, -494231, -301348, 1075997, -25143, 582507, 1525600, 445181], [-306894409, -14428381, 66461, -339837, 81473, -1275657, 894506, 680834, -1088477, 167241], [375262800, 9527092, -721786, -42674, -965124, 311710, -398824, 128042, -1153208, 358234], [610125335, 26699585, -198250, 168205, -5503, 99726, 383528, 913292, 269636, 753585], [452199304, -26557392, 644423, -688074, 1168843, 412686, 10366, 354670, 111778, 1020696], [-471704669, 4935645, -166189, 579451, -557535, -3397542, 345173, 662141, 1064812, -105875], [-1518567443, -6509445, 116201, 72819, -255697, -1543784, -1071610, 737180, -5801, -853047], [1150361463, -8821263, 502815, 212763, 386895, 3066078, -377238, -1432812, -171567, 483921], [-1737839195, 37783091, -255577, -987229, -107709, 729314, 688669, -944150, 471782, 99787], [-1404568271, 18360805, -3757, 368241, 1785595, 2540527, -717868, -1091080, -980561, -571665], [-903479915, 11438251, -167467, -158268, -1736468, 1724530, 985970, 1700120, -127061, -1165245], [-1466764193, -70979505, 482018, 724549, 1349124, 709238, 228738, 432114, 591815, -390387], [2984930586, 8399642, -244107, 5348, 931876, 2411278, 583937, 220886, -97028, -121700], [-799911696, 6513364, -46802, -330576, 2377486, -1371044, 14532, -335058, 761656, -298304], [-240760034, -8569354, -287468, -438374, -1209254, -2239220, 92212, 492148, 497538, -217464], [-2535382093, -103019780, 521853, 188715, 303743, 2955514, -288899, -561368, -57322, 767551], [-120202907, 15336251, -1132076, -417512, -823460, 1625643, 1117280, -653578, -267350, 486617], [-1600637100, -68723944, -494548, -438068, 2674834, -783880, 1702944, -849546, -831844, -62694], [-1342575843, 46216867, -33480, 780301, -134542, -6452077, 31511, -689659, -427033, 197849], [-480010789, 2121633, -328907, 174685, 817245, 844585, -378190, -1640947, 307428, -376299], [101325541, -50928061, 47008, -674902, 455326, 331838, -951963, 1183212, 2919003, -390179], [-1642935029, 23771686, 1232123, 283261, -1535609, 853053, -293948, 802132, 957135, 918155], [-4369247009, -38130559, -193699, 897957, -629697, -5215307, -907206, -438186, 1595029, 153093], [1912256986, 132617614, 723928, -1573602, -975636, -3574455, 612191, -1289113, -1700054, -188030], [-1486612738, -73816280, 149956, -1588636, -672728, -2024488, -885848, 774292, -1263988, -1698472], [2175142766, 23514269, 387575, -2803457, 1037169, -1670785, 1655097, -164166, 2455756, -923612], [4483428672, -18298944, 155530, -628270, 845766, 443900, 389388, -820734, -1266264, 63184], [4725382384, -3859586, 474019, 386976, -833487, -935759, -2485814, 1494394, 1811172, -329158], [-3005219150, 54658106, -2148596, -1159726, 1796142, 1792100, 2513964, -1308900, -2593978, 401192], [4353186776, 15014255, 469149, 138547, -340483, 2708577, -522213, 2069130, -1320616, 1166384], [1840988887, 3268633, 998052, 2589540, 1900472, -2076339, -2548608, -112710, -2016822, 119979], [3711427737, -30590225, -415877, 1242499, -2715379, 1131324, 1489314, -500940, 1505593, -341929], [102715780, 50256016, -1269596, -715281, 811413, 9122556, 1446749, -2554318, -4136495, -561086], [3484989596, -19294094, 672146, -799124, -3709442, 2633910, -554272, -343090, 2595888, -273502], [5830083835, -14287643, -393628, 159511, 1811520, 4338795, -825796, -937825, 1060760, -981549], [32968391, 49779258, -1452266, -180620, -2204635, -6831526, -721257, 3134151, 3008488, -2628661], [1799955091, -115412750, 2783499, 27628, 3013006, 8500505, 1800385, -1772123, 190924, 3094719], [301816657, -11327955, -67658, 274895, -1213890, 2846891, 3220483, -607451, -2878734, 230947], [4720442161, 101440277, -1800547, -901511, -4715139, -1706052, 1486797, 2180652, -716610, -1354753], [3413293040, -42120804, -13992, 258292, 2666618, 3674711, -782997, -1937055, 1742116, 3098064], [-4045472021, 129864791, 30596, -2715157, -3309191, 1410166, 2490574, -223442, 774382, 989639], [666979356, 77150590, 221627, 2761603, 2056065, 6414507, 3157657, -1114550, -5140882, 2184024], [1388755144, -193194054, -446608, -1589499, 8709883, -3742819, 1577854, -3191240, -1795078, 2036570], [-398100394, -146333543, -455709, 3292009, 6163121, -2118885, -3021737, -1364924, -150842, -380700], [6383270980, -164345430, 180421, 909962, 5842149, 7164511, 2466935, -1666075, -1850372, 4028142], [2516635082, -95735162, -787888, 894930, 1971922, -5229108, 1214434, -154838, 2309576, 608324], [-3082076647, -38475851, -253906, 4725389, 447156, 4026232, -1585254, -3204744, 4782353, 1278451], [5576063953, -119094225, -891168, 3777043, -472149, 1432580, -3418192, -184000, -4705276, -2520001], [-4655363119, 104606747, -2548254, 770372, -4785918, 6402681, -2263850, -597218, 5422072, -1014107], [9604420817, -3574947, 1062550, -730839, 2691838, -1342674, -1717784, 952432, 2433277, -3093857], [-3259076197, 85728535, 196127, 1590657, -533101, 6225246, -3777783, -719484, -4023504, -15611], [-5582101542, 21231497, -2706840, -4058556, 5615530, 4408174, 707992, -1227656, -9134380, -819146], [-1620931024, -165936350, 1258062, 133774, -3238462, -3416539, 735268, 3402724, -408154, 1135088], [1428074504, 64718162, 424439, -2723304, 1297581, -9579015, -2420826, 3477774, -481084, 12626], [-4971608199, 153390239, 1054459, 3290421, -10361243, 7685366, -919551, 5762154, 7681918, -637571], [9925756475, -65503161, 2402416, -1804593, 8250582, 4996709, -554209, 1491419, 4628299, 2569987], [-5695189744, -187791060, 3500362, -887588, 5722806, 15618742, 5196484, -5519090, -3510018, 7665222], [3500202889, -103002243, 526782, -5536743, -127464, 13033464, -183238, 83000, -5514723, -1119885], [-8807464046, -5178517, -737637, 1644089, -6836165, -11293913, -1563109, 766424, 9870790, -3566732], [2255497544, 72579249, 3984358, 2280638, 7445192, 1874610, -6158678, -2893208, 1002568, 998196], [-3169929370, 53229632, 3995813, 240573, 6705843, -1133582, 321238, 4139302, 2113285, 270378], [11328928667, -30132603, -3487556, -1025223, -9915687, -14747996, 982224, 2476401, 3863396, -4924353], [3100724214, -114053998, -5185832, -4395618, -5546364, 6520959, 3708539, 1990121, 5953220, -246750], [-11535868087, -20238223, -2016216, -1265261, 9419642, -623098, 3194214, -9163626, -7546539, 1490995], [-8609078641, -100025341, 535892, -6325915, -11015513, 37066, 5263676, -3460261, 759268, 845627], [-7748956515, 47995615, -122651, -3822541, -1797237, 7296574, 2139181, 1490608, -192262, 2522393], [931007598, -383354890, -4022122, -6632078, -872788, -253330, 2996308, -2225624, 1551810, 700052], [10484599329, 60629825, 8430511, 501805, -7394925, 4986866, 395769, 990546, -1164764, 3876887], [-10697901511, 204551949, 1249306, -328631, -5694036, -2384751, -5022061, -2200729, -1749416, -5470021], [-12243762200, 141375263, 3062111, 1826711, -5812781, 19674953, -10536303, 389994, -563814, -3166344], [-22702977984, -73362010, -5314411, -6194760, 606180, -6045468, 3957799, -928274, 5578724, 3443024], [-12970401605, 14814887, 6299505, -2179841, 2640825, 4014379, -9520839, 2229387, 7525811, -112579], [-1440497136, -59659008, 5129899, 25224, 2519479, 12740210, -4639434, 4483446, 72284, -4692024], [20399993994, 17472152, 1945785, 1619294, -2310677, -735879, 3230763, 2602623, -7044958, 5903436], [-14557115542, 5870408, -1262834, 42798, 1219926, 2553390, 3118948, -493682, 4619852, 4923624], [-2385919826, 223946672, -7663320, -3368624, 77846, 4548939, 4162697, 771335, 5861540, -2977450], [-33139377816, 55428154, 1989850, 2733064, -5618256, 3753856, -3255728, 10464640, 10705588, 2621354], [-2687285855, 460144367, -4611583, -1704101, -8228545, 10734399, 6430156, -4788824, 2270267, 168903], [7861957233, -97494855, -2772434, 382315, -2009111, -8562092, 4535232, 1662864, 16169632, 1040405], [20981569701, -105154707, 1998417, 4555795, -1378437, -15915027, -901470, 5536194, 7885453, -2241333], [-12905571857, -436697004, 5743262, 2585010, -1818844, -450425, -327292, 9753812, -4371752, -1028817], [-10036700787, 84742563, 9071406, 1366549, -731774, 12139212, -1812672, 203214, 20046581, 4764035], [-38204922196, -248446854, -4263931, -1512777, 3695199, 680042, 1359074, 453038, 1217053, 1241952], [-6671187268, -170114362, -8837620, -4861060, 2098420, -11228813, 1117022, 3060200, 8096398, -9027964], [-17055186471, -92429919, 2170242, -11296451, 2190989, 9665896, -473786, 2884510, -8278102, -9557035], [-7650893223, 51943141, 4536676, -4626893, 10227290, -15090320, -4819018, 13029476, 309711, -9083745], [-1822417653, 24164583, 1727041, 1935965, -2780303, 8264909, 9905362, 5054158, -2029841, -5475783], [-5607657656, 134615488, -14234236, 1261980, 579712, 5266142, 4039540, -10054754, -9746778, -7635878], [-21274534186, -546398280, 7609048, -1581722, 3706820, 30441049, 1783987, 2970901, -266902, -1567490], [5768123737, -139914019, -1326531, -161245, 9008164, 36375629, 5321042, -3016969, 4042662, 10305689], [12136805352, 38106924, -4741185, 7117222, -7038233, -10294131, -5837020, 6169262, 17284172, -869446], [-752359988, 108811192, 13529871, 9091180, 4254206, 23892564, -10375149, -5851548, 875206, 1358874], [-3551216728, 347405002, 5838605, 5505734, 22129194, 29608444, 1615629, 2113380, -5164252, 5851996], [-11922662334, 390828578, 2280721, 4276042, -10609517, 1152475, -2586264, 7319562, -16792038, 5040300], [-5903909557, -53130023, 6533543, 981631, -16068256, -20009705, -394274, 5646367, 10666368, -4701133], [-21807222103, -136791193, 3892287, 2952001, -1391359, 12313890, 4333221, -15862482, -16960924, 4081307], [-16129563390, -416286870, 1374514, 2628494, 6413740, 36201344, -1410572, 7687684, -7592018, 5835516], [-24379878302, -209527760, -5360020, -856238, 941630, 23844628, 2736726, 10272780, -6531216, -12819976], [-18343392605, -375356893, -2929398, -5962741, 1077974, -31175085, 15858420, -15486816, -5744787, 1065371], [-32223058710, 542223660, 3251257, -3033424, -14728641, 14110481, 1657308, 7086459, 22738539, 5438764], [8648996948, -252717972, 7518014, -7876016, 6126226, -57114726, -632258, 10699714, -2146996, 3964728], [-11440875778, 257905874, 5977568, -1584690, -10745766, -2897418, -19804872, 17038752, 7646264, -7962592], [25413846445, 325448517, 14686277, 312745, -8274833, 16340288, -6303632, 2622250, 7636269, -493675], [14818048752, 384174006, 6865236, -3812630, -15002192, 13831716, -10835950, 16820522, 11624540, -12215272], [-7027269111, -509382526, 2702039, -13893707, -4943071, 33518651, -16346100, 5881428, 24535131, -11041723], [18312375789, 730385121, -10337821, -1908363, 6473635, -67149, 6399231, -7133583, 4565509, 4626987], [2053114616, 29227442, 535990, 487291, -1312227, -26603521, 7397200, 5387116, -12886568, -8285158], [-31124294228, -316734128, 2439940, 10683446, -2162062, -51956737, -11280504, -2601135, 1237203, -3077180], [2557541359, 679567607, 6179228, -8368863, -10347414, -33670103, 6741373, 271663, -9806369, 4530675], [-22069803234, 516527974, -6024563, -4226503, 8609961, 1386416, -16196418, 15157302, -1153601, -4908570], [-6680933589, 158245012, 12734746, 2907254, -5210684, 3687665, -334978, 12656810, 27697730, 10263197], [14874557664, -87263162, -11491298, 13386856, 8875896, -11666813, -179896, -19241272, -23492636, -3706372], [8965451471, -6892829, 11805737, 7672765, -3823351, 6953469, 18079550, 8657108, -7761857, -2977823], [-2887938894, -27984344, -4457502, -18087270, -23998504, -25262130, 13654712, -8974246, -8700426, -295818], [13517924000, -14763952, -6837108, 4209592, -13396500, -43479359, -8397544, 15532751, 3802943, -5259040], [2617932877, 366985689, 10722610, -11100005, -2607386, -49335775, 4695018, -5067288, 14567715, 6839073], [-7121190405, 1247047107, -5113887, -14291805, 25936879, -22067496, 3162888, 5656494, 7857931, 831995], [9016919554, 391711884, -4867487, -5415431, 3572347, -25390739, 8897913, -17164134, -26374772, 12114290], [36323418400, -494981582, 348978, 2448616, 24737888, 369080, -1592832, -12694908, -8241844, 19908110], [5650800801, 731105634, 3079710, -552512, 12563208, 43223115, 16494564, -5507088, -3453512, 4162947], [-11386309698, 147759874, -448570, -22605008, 7221228, 20111954, 4516322, -10511356, -12894, -13216462], [-54390923478, -215340250, -1944588, 6400484, 9266282, 34267139, 16399758, -30092355, -20659133, 9641998], [41049972554, 294972798, 10273965, 17375604, 19236639, 932871, -16974480, 13112592, -5464854, 9166896], [-34523553986, 304587238, -25921143, 14432084, 3765351, 31024427, -12669406, -11544700, -8113730, -13846844], [874172646, -430797896, -18473109, -5224998, -28515148, 10686302, -1136297, -565058, -20416112, -7697482], [6991490139, 1110780939, 27158204, -13261405, -4681224, 38557452, -18047730, -13317036, 19211411, 12925069], [27872814965, 423627385, 20136505, 6154921, 13531731, -5166578, -4827993, -4193382, -10416284, 1997585], [28953100330, -630031424, 7141009, -1867431, 18817197, -16561883, -7891703, -3291314, 8294286, -3486226], [23953368784, 962373232, -2606678, 4088202, -24325868, 94440284, -14424214, 4061048, -25109244, -9804976], [-1842906854, 1069268950, -12269348, 15709121, -6584021, -45611300, 16956773, -12268498, 19735173, -12745028], [15113191134, 426462910, -21932626, -19606652, -26335100, 60578246, -9210778, -16185496, 8469874, -14965322], [30445727951, 807237115, 19164511, 8999745, 16357941, -46748525, -8220517, 29028515, 6053343, -6684667], [2532346534, 1604511604, -24293114, -13263090, -16432234, -5320486, -8522974, -5599024, -3388772, -17613764], [27767620515, 312786373, 3987565, -7556377, -38054657, 14995058, -21181233, 28943331, 58084130, -11936695], [-26294082539, -1161685447, -1843720, -15647165, -20456175, -66522048, -23780364, 3686115, -14195328, -24265411], [-22567602169, 55304963, 8095305, 14492791, 24406195, -24055517, 16276316, -100237, 9394554, 34940653], [23213744657, 901205059, -8389100, -17445103, 1497368, 10335888, 18509388, -29526324, -6469159, -9130597], [-35847664300, 961355755, 15627199, -8225655, -5331267, 26251955, -36265263, 16591824, 43235330, -1732188], [16071390703, -909268601, -4207221, 5858029, -6342765, 25173122, 3616503, -10966212, -27993372, -5998073], [-36205853350, 156824024, -18187651, 366028, 17288551, 42899991, 4107088, -3386048, 6530512, 2139244], [-56989009550, 141085553, -16036389, -8031551, -28401623, -89813181, 7792223, 2906174, -4518242, -2023782], [66685220557, 389092805, 3344024, 45748054, -11696208, -25355137, -23851558, -7912354, 28308970, 5248381], [-48235731849, -564660536, 16335338, 33954658, -6338180, -30214597, -6259264, -5130094, 29065600, 16653277], [17467375768, 1286118420, -2815473, -14056773, -42271217, -9243864, 19611640, -11427422, -925487, -10681792], [13089871032, 859627680, 5103632, 21158116, -30545552, 37254510, -20748014, 5125852, 30403514, 2727516], [-73097323587, -1626409745, -13106424, 32100106, -20465692, 31457503, -16685564, -5527358, 21976266, 5907217], [12694859242, -975124827, 1635503, -6171685, -3454357, 109643681, 26329367, -47169412, -9663118, 20108314], [-14087036333, -1587018216, 678444, -15494314, -24364888, 18769719, 700614, 23776782, 92114620, -1745237], [55365929009, -548692907, 5517271, 20493243, -911925, -24633097, 32230830, -13418262, 10783181, -3631689], [-23740782475, -1773710157, -5936430, -10158119, -7650090, -18956384, 39207790, -12310322, -52586373, 358543], [-7325002722, 718164842, -7082, 39978440, 11140972, 77883695, -34965152, 4243489, -48351231, 3721546], [-714438137, -1057420127, 20210504, -7635889, -32964849, 2054018, -18038468, 26727631, 42270982, 4698875], [-67051103013, -877906763, 1822126, -9950321, 20335802, 60939273, 12194310, 8656569, -30315968, 5342591], [-23861580819, -1002084999, 14678694, 7825131, 31737220, -5089376, 18364634, 13601786, -40308411, 8013375], [-29502437004, -702294332, 26882990, -21537346, 20532860, 70125333, 43668335, -15861463, -24896932, 23393656], [-33866836996, -555666282, -23208142, -13139782, 22546668, 22544344, 18318548, -24670636, -23765852, -7599310], [-20095225740, -2288759938, 3214048, -12791191, -32311899, 32379757, 5198502, 29074872, -12880992, 18530962], [-17271871393, -477779645, -21239384, -16171829, 56767952, -44266044, -1410434, -21271574, -20983295, -7393639], [14287678227, 459505779, 20419480, 7206343, -9390290, -52494116, -44491020, 64353252, 38862625, 8152253], [-62738773211, 817864893, -17402600, -46203501, 17684398, -72185863, -25342436, -47127086, 9736775, -2349375], [66204424335, -2031011747, 2367615, 13981127, 23019031, 25873182, 15443169, -25845267, 15940882, -2128163], [-70516434719, -2501039032, 2377484, -14385388, -4933248, 48879987, -16409970, -5710824, 50263378, -14315545], [-7828471268, 1473741208, 4542656, 4983502, 49294892, -83007434, -5675222, -25982216, -51684714, 675710], [126554437491, -1555378123, 15223055, 27338913, -15822930, 16030609, 299066, 18880289, 45820162, 1078923], [37060125384, 2315934212, 2665024, 17096, 82414030, 38474762, 26043272, 37010498, -19557558, -8448680], [-30760368476, 1654690058, 3175104, -10082036, -47644012, -73593164, 1024572, 53416824, 29823358, -38577618], [1021388972, -2292949898, 7049276, -35109258, -52019146, 4900236, 20930952, 36172074, -23630268, -42025694], [31387144205, -1403126619, -16023689, -43118253, -50226377, -152098161, 2619310, 22681828, 67518019, -9230117], [23713407720, 2690930770, -8928100, -15223792, -12024562, 173698984, 5841730, -15155726, -49520534, 8133350], [-29757988637, -174341105, 15328451, 29744583, -31153577, 94894347, -23794314, -21545415, 70446890, -6990319], [-102189213729, -389026331, 26895535, 17837267, 10783821, 92984404, 8353399, -23759813, 30585242, -846703], [-81018606989, -401210577, 27206832, 27386632, 79792256, 42901624, -8137827, -5112072, -41500951, 36772247], [51914174000, 2144052466, -40650616, 4399148, -89240090, -77672376, -17241316, 11844404, 80024758, -17476036], [-14762290436, -1582795616, -20765491, 29068428, 82193561, 49570724, -10757306, -12655580, -269930, 14558052], [30510242660, 635623326, 14986187, -23818078, -10466081, -66392323, 52909996, 20334196, -31868978, 6289394], [30240887820, 1312099240, -14030765, -40902750, 56267173, 161300865, -1334034, 9080058, -31608982, -18434982], [-100501565999, 1215361954, -13508198, 38560146, -76335618, -27665551, -38019924, 46159656, -43660606, -7810089], [-50990833507, 1100860693, -12059643, -6546229, -18893207, 174142524, 17485521, -12364698, 2728348, -15865937], [33244777666, 2519325346, -3942241, -216264, 73377262, 101225986, 25875211, 23237932, -27026090, 6889464], [102883091727, 3254408087, 26219088, 60960945, 47067198, 10291465, -24876624, 29368074, 22255309, -10430389], [-32021350868, -1592344254, -22775234, -24593768, -3905778, -80271777, 3002627, -37483933, -62831810, 739292], [69161454549, -1638152309, 41154179, 18065387, -48585921, -8269351, -45700800, -1460976, 67553767, -28245109], [-168981217475, -239774677, -13024619, -50770703, 8560403, 63466003, -18884728, 2413751, -33572828, -63605365], [6867670417, 3401517067, 18979155, -51634579, 46574363, 6011945, 12795036, -62581044, 43351989, 3379679], [-72607004421, 120006589, 30990597, -12618611, -43899111, 2649164, -1220329, 13510298, -5934450, 26295379], [127532403447, 40364813, -35482699, -25940091, -7250892, 3594201, 514102, 17440645, 56584286, -25943797], [30511321394, 85230253, -22377940, -55021958, -9860024, -155645079, -17097379, 42723818, 26647761, -39321658], [-102473398447, 1822462967, -13353997, -54309305, 3289989, 7530014, 26445198, -57851424, -79252391, 12422023], [-8991472239, -293158435, 22627871, 47582989, 16184735, 33053224, -3632159, -16779890, 96626242, 39983575], [35602225708, 895321256, 18271375, -34362150, -34417997, 24480981, -33471714, 56801589, 44561061, -37144306], [-16187984507, 201671695, 22531415, -19666151, -55596619, -51215091, -37809104, -53397446, 78959527, 35949559], [-26889888763, 3147631019, 20020902, 13436794, 48906456, 4608074, -47371803, 5650032, 38253553, -20120895], [-20827013110, 2272680626, -2410492, -42353636, 29215670, -29939891, 90958749, -38422029, 38251558, 2217850], [-23786076821, -197409826, -47213568, 38092512, -24378305, 97459246, -41445223, -29677993, 27567302, 14687647], [-97971356402, -3757861316, -5182691, -41404300, -63462716, 46159878, -36946477, -31645402, 18882634, -19202490], [109498678060, -553277408, -11677080, 40684486, -110743934, -23634758, -60075700, 96632960, 182034188, -52504384], [-9773919169, -1263492733, 2872630, -37868963, -84838352, 71252606, 79091710, 54756220, -34669897, -40636763], [-153903185063, -1930899901, -31872256, -2008647, 58338443, 44011944, 98024038, -32906948, -59366930, -18286413], [-107899786000, 2813588934, -38752454, 29359709, -17046131, -16673535, -70131856, -11583952, 50271006, -42884678], [120400375722, 2064174430, 9197537, 28715664, 64764977, 22967276, -18357672, -16981152, -117795368, 36974694], [122403306636, 1709947356, -35015060, 16782553, -56301615, -92628380, 14677139, -51636502, -39728223, -1291074], [-51122231430, 1693399076, 39964800, 58508670, 7125460, 128497338, -3887548, 69054416, 24591456, 25578114], [-7387514695, -1652579783, 33828187, 25576423, 100935629, 255896653, -10113450, -68218008, -129652755, 68107359], [51744771686, -1150744405, 59864743, 55479519, 108935129, -120747477, -104667631, 25513916, 30072928, -9611954], [25787389530, -1789300786, 26272521, -2707008, 41375783, 105235076, -53287818, -64977192, -99459766, 57737470], [29201024365, 1816140001, 22597227, -26104868, -109722460, 101023061, 13904121, 83602416, 13196708, -8463853], [135501482802, -3934803102, 15525656, -9277170, -65937544, -277694786, -99542962, 46456268, 52604572, -9736284], [-74826879182, 2654362202, 2382796, 31394562, 43795490, 11906114, -58275920, -44748218, -28674430, 27274986], [10538592567, -699091081, 37007530, -50574389, -48966598, 41443412, 57737520, -39786588, 54994701, -6263535], [-36670285467, -1291228751, -77588204, 15761582, 88706092, -51043289, 53069310, -8969358, -104738304, -24463211], [15723651652, -1908165837, -10502009, -66719421, -58522045, -187012017, -33195961, 26644562, 163846286, -105219222], [-58228479310, -128323470, -67624943, 58490902, 171214247, 67528437, 20906780, -16172131, -69530709, 22825572], [51294413159, -343504570, 3628121, 4528181, 89398251, -159098368, -45926215, -32830480, -61657540, -17673341], [38672681136, -5577263118, -28208361, -21746294, 25754767, 114845379, 5073194, -71025520, 23202668, -2489086], [-112233585615, 310217959, -33724847, 47339603, 151876193, 40225602, 43051217, -83159980, -82719148, -20159809], [-263638441156, 4149333996, -25320003, -39775588, -90810370, -52776198, 93021807, -25635186, 34164562, 17327134], [-46859728300, 395351860, 30138564, -69512252, 51474894, -156745558, 54010894, -24007682, -76207158, 55970320], [-2610330484, -605140012, -2748401, 53474132, 34996679, -156721148, 29378048, 45908264, 78581840, -41811244], [-51421399656, -7516887784, -42382844, 22536960, -34602454, -111694102, -11332044, -3263346, -41159500, 64068006], [63605885393, -501566093, 46376262, -12822325, 103788245, 67206342, 55433244, -35201730, -148859170, 15357495], [54804302209, -1968228223, -17616099, -86606609, -20091692, -362438093, 108561634, -76751795, -53982702, 4127917], [27964608478, -1520627960, -12085726, 179440034, 58964438, 14457628, -39944494, 29396360, -216678146, 11908256], [-134266208329, -1695864893, 31534996, 23528419, 173013480, -54747733, 80585028, 32992908, -77957907, 80014947], [77217149299, -18298139, -31642285, -16530565, -87130887, 115458508, -21584338, -101946556, -42908941, -77393717], [-2726948777, 4704621109, -20821851, -21889873, -84023691, 64213446, -86493025, 22388882, -16913502, -8839867], [-30857324084, 2843755750, -129138324, -17580076, 9420110, -108667416, -16743148, -54087520, -10973680, -40645428], [36374949550, 4324841552, 17724933, 23069130, -11719871, -23610741, 74224500, -81200688, 68316264, 106382196], [-103474901545, -2462033249, 55095680, 19952918, 48989152, -258779395, 114216350, -5921218, -134732776, 5863783], [-5338704585, -1518529876, -66179967, 50759869, 78177951, 141123687, 31467288, 1363884, 24434139, 27841855], [-115778127155, 1431120745, 86738453, 15174951, 58453333, 59537319, -86752326, -12204231, 32987648, 25335911], [5039881842, -3089913850, 38939430, 62227638, 69637248, -443136566, -91824504, 59056956, 178370962, 29280128], [-101029097256, -1933697084, -25381106, -57763972, 51577878, -80650718, -27740384, -10596200, 47822384, -15890140], [-253847264385, 2138095274, 14784791, 15228210, 2221810, -52202783, -66874129, -39259441, 116320178, -8738797], [93692365843, 1610115103, 86727068, -20700225, 181007508, 111906669, 134246949, 25184187, 54373381, 102605499], [-181710157506, 2061809044, 80067635, 38858050, 121509549, -4823059, 45169462, -20946302, 136285164, 176034920], [119776796021, -871688632, 39915346, 59659542, 26618486, 184628425, -64657904, 13360168, -122091798, 78815315], [-24675911398, -86101872, -22834232, -24010478, -174018928, 178265518, 54861424, 66886066, -26176048, -45315188], [-108219774053, -2018175315, -63402045, -27149407, -76371237, 370721415, 58713282, -67866363, 18068594, 28439001], [129108789198, -867768874, -78599153, -40533197, 21983607, 281016959, -61521561, 10980678, 63002476, -71231734], [-223486165298, -2428570886, 64679758, 87632641, -51587791, 6946108, -24833085, 83252514, 165287727, 57914160], [142102526427, 2423037517, 33561225, 9191469, -46893530, -404225697, -1645390, 47573459, 63098252, 18701887], [-50566981744, -2129037957, 15454983, -27945871, 41785799, 7614453, 69220275, 54801858, 183231568, 120164854], [-415818932517, -3853981681, 29305961, 17035825, -52016109, -43654726, -47578421, -57708374, -3867038, 74232391], [83068043460, -345885436, 7251454, -101959872, -12228844, -395423092, -78269358, 71505996, 39627176, -75762606], [276629144711, -1514275271, -68171858, 76330757, 124342102, -8170435, 63191611, -78787997, -158089123, 16751375], [-89980720629, 316262219, -54258677, -97591431, -98496853, 54061887, 156742776, -29544495, 100537972, 55422541], [-213935917145, -1381088258, -44871603, -36321520, -111168388, 28067097, 2976155, -19864087, -83732158, -79338573], [64145489455, 2069236447, -86254153, -113378425, -163777371, 302968486, 63042485, 23137850, -167460076, -63839789], [-7517649791, -2054851943, 26897648, -10327753, 56370514, -364243864, -120469166, 63697108, 303914639, -55162505], [-265484156903, 3387686011, -3313742, 17974485, 60297561, -212746254, -123369046, 7852718, 84160180, -26170421], [-65847340499, -5052134295, -19244224, 74473436, -134823856, 124585632, -36407827, 86841740, 9364063, -84873007], [18153713279, -304294145, -47948203, -53184215, 233843309, 47807875, -18288326, -132493283, 17525574, -107021071], [-21104154137, -1927809137, -138749840, -66590107, -155070257, 197170676, 110657320, -84756575, 68891228, -42481441], [309419440778, -830108218, -91847718, -8382288, -97597208, 91718906, -26006050, -5874604, 83447410, -42747124], [34631337755, 5031178619, -50623415, 21303693, 53528524, -363617047, -14633524, -54814081, -176432750, -52130753], [16930175845, -410676251, -63626213, -39589095, -49883761, 368916682, -50812827, 68906532, -296962984, -10114911], [154678739044, 4557060039, 88508123, 43793805, 97221259, -102663401, 118090325, 39730262, 59521356, -10209356], [-42057042095, -3707063757, 69483564, 13535692, 7431722, 433373698, 157624133, -95500156, -126259999, 141817649], [63181190893, -3730158315, 73401570, 24768671, -138505646, -396269817, 39652160, -6885460, 68162757, 148170653], [-32119288033, -1942583099, 19753348, 16344435, -131088412, -83414248, -112175504, -136674662, -138444083, -180403463], [347696230132, 779720508, 75314596, 759754, -45790396, -306593188, -148726222, -168929182, 69922840, 109685210], [-75775520201, -1806915757, -6062804, -32492876, 168741288, -439369131, -79428466, -58156366, -165799548, -28448025], [-22819611320, -4595772534, 81536118, 13523208, 163930156, 233677612, 132202170, -90467832, -140292222, 252505728], [-259689351431, 618697409, -140694995, -110019713, 53274793, 544803193, 148269572, -52208152, -38513829, 22651887], [48244713935, 2487724525, -102765861, 68841949, -31107328, -352737331, 46293482, 31171709, -68615968, -79336261], [184829023205, -1804292351, -4431068, 42786211, 137730802, -224289562, -3236164, -147286150, -61590263, 83283587], [-122506240072, -6723791874, 88318505, 143466935, -253760435, -78037025, -23615281, -121684498, 26727806, 87265264], [-59528520477, -4836373767, -44632383, -16173157, -28741857, -181014699, -45634468, 192351119, -171398788, -139573215], [72269510020, -9717297666, 129431226, 51596778, -41872740, -250698870, -111739394, 85113718, 62667426, 84995292], [338747770747, -3199502129, -168215756, -19994771, -76479036, 274735033, -140237613, -96145359, -50736659, -8202805], [-292335326372, -4145841808, 59572559, 60824088, -44318507, -71469493, -76804840, 45279548, 88811026, 109373214], [343084826762, 4177508872, 87644319, 143911052, 99510317, -93189497, 91285864, 143597461, -179729459, 70394980], [22398416997, -3331573105, -41178467, 8414039, -26997253, -213671804, 66118998, 198108144, -159174715, -38012569], [-492898412989, -9593469239, -32903327, -46930148, 68688702, -248068826, -37761632, 6730960, 222381859, -109253215], [-132011805495, -4113354369, -5554664, -98897199, -51374741, -307910002, -79169800, 16502624, 126623618, -135249657], [106129834452, -422966560, -31967630, 14694710, -87878068, -266389500, -7179876, 270661116, 385284210, -130853828], [-154306629469, -4965019597, 79742188, -63670761, -240054748, -245547338, -95646488, 161935750, 338589843, -7539259], [523562786140, 4107647786, -63025019, -125728430, -195590783, -208309923, -107474848, -7075825, 71731999, -41522290], [35678973974, 4733237420, 116415779, 5496093, 320551111, 217930802, -27582992, -114758738, -149931473, -139516986], [96585816750, -11385869892, -18263203, 264255484, -2408382, 208112618, 14625599, 189811916, -88702126, 43445838], [-50202090180, 1314936234, -122129909, -192779135, -245823853, 54858662, 239982202, -281396306, -14692835, -54822160], [-276477055015, -3733048233, 71948080, -86663888, 2733074, -60675217, 143581084, 241670938, 275734294, -51184207], [308680308270, -983979966, -57768625, -64796287, -39885143, 85383660, 39174408, 183934278, 457459719, -1175646], [488030988314, 9699270438, -52090975, -27251064, 190707818, -296380770, 61575593, -124996258, -127011214, 5907992], [-344716031746, 5112313712, 106351281, 43898472, 7450769, -96543033, 7402788, 45068670, -96739418, 164947892], [-492332505247, 607529149, 128370496, -41442013, -130792524, 80370797, 66941945, -45508855, 54309523, 123419829], [-759341977751, 8447594947, -48869309, -83946274, -207134796, -100695802, 146637490, 26844508, -189965009, -17251161], [-565959675935, -2771355954, -26217737, 114233936, 30693844, -210878281, 144298169, -50523541, -375993038, -15592947], [315882504085, 7067509893, -28367400, -135954606, -92339226, -188408283, 136422748, 250328386, -50230956, -32855067], [176050938428, -6573072214, 148133838, -37426278, 95388414, 297944868, -60562268, -137183918, -222254524, -15855854], [76367628174, 29298434, 31285698, 127353411, 291288707, 556863664, -29752407, -121963938, -134229357, 148803768], [202975379334, -1124971374, -904306, -114127290, -51673310, 675178002, 43419950, 99170810, -94696772, -4768206], [-344296201317, -6942131297, 166112433, 40927113, 202727663, 177176085, 288557478, -62624562, -246227193, 74995089], [151573047098, 1233708644, 182603278, 71170514, -68669142, -194857129, -8726169, 109280007, 235948700, 212214098], [-508540900305, 273212693, -23638633, 44322245, 65148369, -60453206, -199548788, -57999530, -62595459, -30557289], [97928930367, -519711235, 132924655, -59863881, -52534319, 418560266, 227515573, -168910256, -156420356, 222053479], [102829656207, 2927209927, -83135075, 169901603, -91755277, 157124977, -53717670, -141487803, -318822098, -90219171], [-177654420609, -4629853798, 74402384, 68987604, 148285458, 655906847, 205328552, -298728286, -316797276, 224924863], [146846832345, -2605042650, 11718356, 233265590, 143854696, -11107941, -200466936, 17939808, -8199894, 33717243], [150086604966, -1302916775, 10727483, 154671169, 278057897, -539534177, 56979159, 81347256, -169901934, 8630468], [-261841847583, 15000274781, 2565016, 90099223, 330522928, -238686810, -47691536, -87266318, -188303057, 67228355], [-20919983065, 646346615, 16052851, 91276711, 83353937, -539302619, 30944778, -29930946, 226414921, 46402985], [124933295471, 5570196325, -52461531, 53780487, 266727453, 626233576, 35822466, -86954400, -382547349, -115836537], [76892833414, -695871876, -111580917, -155446196, -40723218, 34984184, -127750193, -121823084, -68563192, -79095562], [-271004637918, -5098384276, 19619409, 220514954, 85223823, 241951779, 32526525, -235963857, -304605824, -80516864], [-339420926654, 4190519336, 111920338, -20139692, -143840782, -216553056, -30090762, -62189052, 160811558, 213306400], [-126883569058, -8601791550, -8706246, -10184900, 267434388, 726941894, 135610982, -39363736, -62603518, 10362824], [41520348086, 5501512759, -4238458, -93998278, -285216012, -24482048, -77820602, -18813536, 88130360, 13534522], [811433479705, 8164015682, 131822550, -126608718, 112991390, 598791483, -31542742, -197552512, -19626554, 65320817], [24222916292, 6773680112, -101965039, 73369923, -159469839, -210613492, 146184250, -155201210, -318026721, 86773180], [59370044389, 1623192885, 22708968, -25607527, -94333780, 663250014, -240119578, 9071042, -154453847, -102981365], [167271868587, -7970557130, 67153855, 59592483, -121545003, 56181440, -34713287, 71055088, 248248538, -21745893], [-121855524770, -5353187858, 13226697, -252986440, -141210840, 482032218, 146774057, 6380138, -37606956, -100471672], [543765747561, -1194711943, -75529304, -304394117, 4594138, 79703988, -123050968, 212674376, 133459861, 65641283], [548944010786, -3926068724, -178573813, -24419228, -153601041, 69753369, 137764898, 15109067, -338790649, 89472024], [732344098239, 1449169769, 62937421, 155873315, 1893265, 814279304, 5681437, -119498378, -543912996, 123805459], [-477413617495, -9897104015, -93047482, 186226321, 21478944, 272795963, -125486048, 79114714, 234994509, -178552855], [589844276891, 4375360873, 57317783, 13383667, 89079587, 1409886358, 79343398, -232983734, -498506379, 168120515], [-107968162669, 6434496549, 46174639, 238060313, 119173799, -466217301, 207951262, -6027392, -159962273, 22171461], [1033788403351, 143336791, 87389816, 9534695, -20141289, 151639216, 277218320, 232487120, 64036058, 184109359], [376657511774, 1848440601, -148012692, -46120882, 259393716, 384416301, -16415903, 27485494, -492007231, -99813774], [498940639811, -9082855091, 153596398, -92441240, 266524848, -215707925, -129636540, 8807826, 133482454, 154558991], [475445633539, 3978715161, 204000146, -292347431, -9607418, -752602609, 290744439, -90086343, -171400461, 94373135], [77831363156, -1169296250, -50388614, -165310260, 94951452, -46900632, 253676358, -379529352, -183661178, -4593866], [415739410945, -13180019081, -6687169, 19506902, -443098818, 271223294, -104790818, 373722136, 43486963, -209314069], [-476009357075, 18176324845, -102640447, -173646789, -299521799, 306615409, -21404516, 1216354, -400864799, -149570169], [1245538426821, 5765716185, 38862019, -97396353, -1896355, -232751020, 128120447, -334460098, -75268506, -38314429], [-113984219993, 10253943462, 30649216, 184717924, 179783044, 70989949, -201888230, -271660190, 179663374, 119014871], [870273826604, -6567091592, -239471500, 62862598, 81349736, 212900110, -167520290, 89697814, -28497768, -47665780]]
